@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.63';
+our $VERSION = '0.64';
 
 use Dist::Zilla 6.0;
 
@@ -63,7 +63,6 @@ use Dist::Zilla::Plugin::Test::ReportPrereqs;
 use Dist::Zilla::Plugin::Test::Synopsis;
 use Dist::Zilla::Plugin::Test::TidyAll 0.03;
 use Dist::Zilla::Plugin::Test::Version;
-use List::Gather;
 use Parse::PMFile;
 use Path::Iterator::Rule;
 
@@ -468,14 +467,26 @@ sub _next_release_plugin {
 }
 
 sub _explicit_prereq_plugins {
+    my $self = shift;
+
+    my $test_more = $self->_dist_uses_test2
+        ? [
+        'Prereqs' => 'Test::More with Test2' => {
+            -phase       => 'test',
+            -type        => 'requires',
+            'Test::More' => '1.302015',
+        }
+        ]
+        : [
+        'Prereqs' => 'Test::More with subtest' => {
+            -phase       => 'test',
+            -type        => 'requires',
+            'Test::More' => '0.96',
+        }
+        ];
+
     return (
-        [
-            'Prereqs' => 'Test::More with subtest' => {
-                -phase       => 'test',
-                -type        => 'requires',
-                'Test::More' => '0.96',
-            }
-        ],
+        $test_more,
 
         # Because Code::TidyAll does not depend on them
         [
@@ -491,6 +502,17 @@ sub _explicit_prereq_plugins {
     );
 }
 
+sub _dist_uses_test2 {
+    my $rule = Path::Iterator::Rule->new;
+    my $iter = $rule->file->contents_match(qr/^use Test2/m)->iter('t');
+
+    while ( my $file = $iter->() ) {
+        return 1;
+    }
+
+    return 0;
+}
+
 sub _prompt_if_stale_plugin {
     my $name = __PACKAGE__;
     return (
@@ -730,7 +752,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.63
+version 0.64
 
 =head1 DESCRIPTION
 
